@@ -40,9 +40,9 @@ def create_label_dict(dataframe, label_col):
     return label_dict
 
 
-def label2id(dataframe, label_col, label_dict, multi_class=False):
-    if multi_class:
-        dataframe['label'] = dataframe[label_col].apply(lambda c: [int(c == k) for k in label_dict.keys()])
+def label2id(dataframe, label_col, label_dict, multi_label=False):
+    if multi_label:
+        dataframe['label'] = dataframe[label_col].apply(lambda c: [int(k in c) for k in label_dict.keys()])
     else:
         dataframe['label'] = dataframe[label_col].apply(lambda c: label_dict[c])
     return dataframe
